@@ -45,7 +45,7 @@ use std::fmt;
 /// The Vector of command line arguments presented to the executable in `std::env::args().collect()` is used to define the `Command` struct fields.
 ///
 /// See the documentation for the `Command` struct methods and fields to learn how to use the parsed data in your command line interface application logic.
-#[derive(Debug)]
+#[derive(Clone, Debug)]
 pub struct Command {
     /// Vector of ordered command line arguments
     pub argv: Vec<String>,
@@ -383,6 +383,32 @@ impl Command {
         false
     }
 
+    /// Returns boolean for the question "Do the command arguments to the executable match the argument strings and sequence in `needle_vec` Vector?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.contains_sequence(vec!["filter", "help"]) {
+    ///     // the command sequence was identified as "[executable] filter help"
+    /// }
+    /// ```
+    pub fn contains_sequence(&self, needle_vec: Vec<&str>) -> bool {
+        // confirm that the request does not exceed the length of arguments in the command
+        // subtract value of 1 for the executable which is excluded in this test
+        if needle_vec.len() > (self.argv.len() - 1) {
+            return false;
+        }
+        for (index, arg) in needle_vec.iter().enumerate() {
+            if *arg != self.argv[index + 1] {
+                return false;
+            }
+        }
+
+        true
+    }
+
     /// Returns Option<&String> definition for a key defined by `needle`
     ///
     /// Returns `None` if the option was not used in the command
@@ -476,6 +502,51 @@ impl Command {
     pub fn get_index_of(&self, needle: &str) -> Option<usize> {
         self.argv.iter().position(|x| x == needle)
     }
+
+    /// Returns boolean for the question "Is the command a help request with a `-h` or `--help` flag?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.is_help_request() {
+    ///     // handle help request
+    /// }
+    /// ```
+    pub fn is_help_request(&self) -> bool {
+        self.options.contains(&"--help".to_string()) || self.options.contains(&"-h".to_string())
+    }
+
+    /// Returns boolean for the question "Is the command a version request with a `-v` or `--version` flag?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.is_version_request() {
+    ///     // handle version request
+    /// }
+    /// ```
+    pub fn is_version_request(&self) -> bool {
+        self.options.contains(&"--version".to_string()) || self.options.contains(&"-v".to_string())
+    }
+
+    /// Returns boolean for the question "Is the command a usage request with a `--usage` flag?"
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// let c = commandlines::Command::new();
+    ///
+    /// if c.is_usage_request() {
+    ///     // handle usage request
+    /// }
+    /// ```
+    pub fn is_usage_request(&self) -> bool {
+        self.options.contains(&"--usage".to_string())
+    }
 }
 
 // Tests
@@ -855,6 +926,29 @@ mod tests {
         assert_eq!(c1.contains_any_option(vec!["subcmd", "bogus"]), false);
     }
 
+    #[test]
+    fn command_method_contains_sequence() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "subcmd".to_string(),
+            "subsubcmd".to_string(),
+        ]);
+        assert_eq!(c.contains_sequence(vec!["subcmd", "subsubcmd"]), true);
+        assert_eq!(c.contains_sequence(vec!["subcmd"]), true);
+        assert_eq!(c.contains_sequence(vec!["subsubcmd", "subcmd"]), false); // wrong order fails
+        assert_eq!(c.contains_sequence(vec!["bogus", "subsubcmd"]), false); // any invalid string fails
+        assert_eq!(c.contains_sequence(vec!["subcmd", "bogus"]), false); // any invalid string fails
+        assert_eq!(
+            c.contains_sequence(vec!["subcmd", "subsubcmd", "toomuchinfo"]),
+            false
+        ); // fail with too many argument requests c/w command that was entered
+        assert_eq!(c.contains_sequence(vec!["bogus", "bogus", "bogus"]), false); // fail all invalid strings
+        assert_eq!(
+            c.contains_sequence(vec!["subcmd", "subsubcmd", "more", "evenmore", "lotsmore"]),
+            false
+        );
+    }
+
     #[test]
     fn command_method_get_definition_for_def_present() {
         let c = Command::new_with_vec(vec![
@@ -923,4 +1017,57 @@ mod tests {
         assert_eq!(c.get_index_of("-o"), Some(1));
         assert_eq!(c.get_index_of("missing"), None);
     }
+
+    #[test]
+    fn command_method_is_help_request() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "-h".to_string()]);
+        let c2 = Command::new_with_vec(vec!["test".to_string(), "--help".to_string()]);
+        let c3 = Command::new_with_vec(vec!["test".to_string(), "-help".to_string()]);
+        let c4 = Command::new_with_vec(vec!["test".to_string(), "--h".to_string()]);
+        let c5 = Command::new_with_vec(vec!["test".to_string(), "--else".to_string()]);
+        let c6 = Command::new_with_vec(vec!["test".to_string(), "h".to_string()]);
+        let c7 = Command::new_with_vec(vec!["test".to_string(), "help".to_string()]);
+
+        assert_eq!(c1.is_help_request(), true);
+        assert_eq!(c2.is_help_request(), true);
+        assert_eq!(c3.is_help_request(), false);
+        assert_eq!(c4.is_help_request(), false);
+        assert_eq!(c5.is_help_request(), false);
+        assert_eq!(c6.is_help_request(), false);
+        assert_eq!(c7.is_help_request(), false);
+    }
+
+    #[test]
+    fn command_method_is_version_request() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "-v".to_string()]);
+        let c2 = Command::new_with_vec(vec!["test".to_string(), "--version".to_string()]);
+        let c3 = Command::new_with_vec(vec!["test".to_string(), "-version".to_string()]);
+        let c4 = Command::new_with_vec(vec!["test".to_string(), "--v".to_string()]);
+        let c5 = Command::new_with_vec(vec!["test".to_string(), "--else".to_string()]);
+        let c6 = Command::new_with_vec(vec!["test".to_string(), "v".to_string()]);
+        let c7 = Command::new_with_vec(vec!["test".to_string(), "version".to_string()]);
+
+        assert_eq!(c1.is_version_request(), true);
+        assert_eq!(c2.is_version_request(), true);
+        assert_eq!(c3.is_version_request(), false);
+        assert_eq!(c4.is_version_request(), false);
+        assert_eq!(c5.is_version_request(), false);
+        assert_eq!(c6.is_version_request(), false);
+        assert_eq!(c7.is_version_request(), false);
+    }
+
+    #[test]
+    fn command_method_is_usage_request() {
+        let c1 = Command::new_with_vec(vec!["test".to_string(), "--usage".to_string()]);
+        let c2 = Command::new_with_vec(vec!["test".to_string(), "-u".to_string()]);
+        let c3 = Command::new_with_vec(vec!["test".to_string(), "-usage".to_string()]);
+        let c4 = Command::new_with_vec(vec!["test".to_string(), "--else".to_string()]);
+        let c5 = Command::new_with_vec(vec!["test".to_string(), "usage".to_string()]);
+
+        assert_eq!(c1.is_usage_request(), true);
+        assert_eq!(c2.is_usage_request(), false);
+        assert_eq!(c3.is_usage_request(), false);
+        assert_eq!(c4.is_usage_request(), false);
+        assert_eq!(c5.is_usage_request(), false);
+    }
 }
