@@ -86,7 +86,7 @@ pub fn parse_last_arg(arg_list: &[String]) -> Option<String> {
 }
 
 /// Returns `Options<Vec<String>>` with Vector of arguments following a double dash `--` command line argument idiom.
-/// Returns None if there was no double dash idiom present or there are no arguments following the double dash argument.
+/// Returns `None` if there was no double dash idiom present or there are no arguments following the double dash argument.
 pub fn parse_double_dash_args(arg_list: &[String]) -> Option<Vec<String>> {
     for (index, value) in arg_list.iter().enumerate() {
         if is_double_hyphen_option(&value[..]) {
@@ -102,6 +102,38 @@ pub fn parse_double_dash_args(arg_list: &[String]) -> Option<Vec<String>> {
     None
 }
 
+/// Returns `Option<Vec<String>>` that includes unique short options parsed from the command arguments, including any multi-option short syntax options.
+/// Returns `None` if there were no short options in the command
+///
+/// # Remarks
+/// Note that this function is not UTF-8 compliant and enforces a stricter character set definition than other areas of the library. It will not properly parse multi-option short syntax options that include characters outside of the Unicode Basic Latin set.  This function supports the multi-option short syntax argument style defined in the POSIX guidelines (i.e., POSIX option strings should include only characters in the alphanumeric subset of the Unicode Basic Latin set).
+pub fn parse_mops(arg_list: &[String]) -> Option<Vec<String>> {
+    let mut return_vec: Vec<String> = Vec::new();
+
+    // iterate through the option argument list argument
+    for arg in arg_list {
+        if !arg.starts_with("--") {
+            // exclude long option format
+            let t = &arg[..];
+            for x in t.chars() {
+                // iterate through characters in short options
+                if x != '-' {
+                    // assume any character in a short option is a unique option
+                    let option_string = format!("-{}", x); // format as `-[x]` for storage
+                    return_vec.push(option_string);
+                }
+            }
+        }
+    }
+
+    // if there were no short options parsed with this function, return `None`
+    if return_vec.is_empty() {
+        None
+    } else {
+        Some(return_vec)
+    }
+}
+
 /// Returns boolean for the question "Is `needle` a definition option?".
 ///
 /// # Remarks
@@ -111,6 +143,20 @@ pub fn is_definition_option(needle: &str) -> bool {
     needle.contains('=')
 }
 
+/// Returns boolean for the question "Is `needle` a double hyphen option?".
+///
+/// # Remarks
+/// The `--` command line idiom is used to indicate that arguments following this indicator should not be parsed as options.
+pub fn is_double_hyphen_option(needle: &str) -> bool {
+    needle == "--"
+}
+
+/// Returns boolean for the question "Is `needle` a multi-option short syntax (mops) style option argument?"
+pub fn is_mops_option(needle: &str) -> bool {
+    // must have single dash syntax with more than one option character
+    needle.starts_with('-') && !needle.starts_with("--") && needle.len() > 2
+}
+
 /// Returns `Vec<String>` of definition option parts with two index positions.
 ///
 /// These index position definitions are:
@@ -121,14 +167,6 @@ pub fn get_definition_parts(needle: &str) -> Vec<String> {
     vec![String::from(opt_def[0]), String::from(opt_def[1])]
 }
 
-/// Returns boolean for the question "Is `needle` a double hyphen option?".
-///
-/// # Remarks
-/// The `--` command line idiom is used to indicate that arguments following this indicator should not be parsed as options.
-pub fn is_double_hyphen_option(needle: &str) -> bool {
-    needle == "--"
-}
-
 // Tests
 #[cfg(test)]
 mod tests {
@@ -290,16 +328,46 @@ mod tests {
         assert_eq!(parse_double_dash_args(&test_vec), None);
     }
 
+    #[test]
+    fn function_parse_mops() {
+        let test_vec = vec![
+            String::from("--lng"),
+            String::from("-hij"),
+            String::from("-o"),
+        ];
+
+        // should include all short options with multi-option short syntax options parsed to unique individual option items
+        let expected_vec = vec![
+            String::from("-h"),
+            String::from("-i"),
+            String::from("-j"),
+            String::from("-o"),
+        ];
+
+        assert_eq!(parse_mops(&test_vec), Some(expected_vec));
+    }
+
+    #[test]
+    fn function_parse_mops_without_mops() {
+        let test_vec = vec![
+            String::from("--lng"),
+            String::from("--hij"),
+            String::from("--output"),
+        ];
+
+        assert_eq!(parse_mops(&test_vec), None);
+    }
+
     #[test]
     fn function_is_definition_option_true() {
         let true_defintion = "--option=definition";
-        assert!(is_definition_option(true_defintion) == true);
+        assert_eq!(is_definition_option(true_defintion), true);
     }
 
     #[test]
     fn function_is_definition_option_false() {
         let false_definition = "--option";
-        assert!(is_definition_option(false_definition) == false);
+        assert_eq!(is_definition_option(false_definition), false);
     }
 
     #[test]
@@ -324,4 +392,21 @@ mod tests {
         assert_eq!(is_double_hyphen_option(false_definition_2), false);
         assert_eq!(is_double_hyphen_option(false_definition_3), false);
     }
+
+    #[test]
+    fn function_is_mops_option() {
+        let true_definition = "-mpn";
+        let false_definition_1 = "-o";
+        let false_definition_2 = "--output";
+        let false_definition_3 = "command";
+        let false_definition_4 = "--";
+        let false_definition_5 = "-";
+
+        assert_eq!(is_mops_option(true_definition), true);
+        assert_eq!(is_mops_option(false_definition_1), false);
+        assert_eq!(is_mops_option(false_definition_2), false);
+        assert_eq!(is_mops_option(false_definition_3), false);
+        assert_eq!(is_mops_option(false_definition_4), false);
+        assert_eq!(is_mops_option(false_definition_5), false);
+    }
 }
